@@ -187,12 +187,11 @@ impl YedbClientAsync {
         if let Some(ref mut v) = self.stream {
             Ok(v)
         } else {
-            let stream: ClientStream;
-            if self.path.starts_with("tcp://") {
-                stream = ClientStream::Tcp(TcpStream::connect(&self.path[6..]).await?);
+            let stream: ClientStream = if self.path.starts_with("tcp://") {
+                ClientStream::Tcp(TcpStream::connect(&self.path[6..]).await?)
             } else {
-                stream = ClientStream::Unix(UnixStream::connect(&self.path).await?);
-            }
+                ClientStream::Unix(UnixStream::connect(&self.path).await?)
+            };
             self.stream = Some(stream);
             Ok(self.stream.as_mut().unwrap())
         }
@@ -240,7 +239,7 @@ impl YedbClientAsync {
         let frame_len = u32::from_le_bytes([buf[2], buf[3], buf[4], buf[5]]) as usize;
         let mut buf = vec![0_u8; frame_len];
         stream.read(&mut buf).await?;
-        let response: JSONRpcResponse<Value> = rmp_serde::from_read_ref(&buf)?;
+        let response: JSONRpcResponse<Value> = rmp_serde::from_slice(&buf)?;
         if response.id != req.id {
             return Err(Error::new(ErrorKind::ProtocolError, "invalid response id"));
         }
